@@ -19,6 +19,7 @@ import time
 import logging
 
 import numpy as np
+import scipy.io as spio
 
 from hdidx.distance import distFunc
 from hdidx import indexer
@@ -55,7 +56,7 @@ def create_random_data(ntrain=10**4, nbase=10**4, nquery=10**1):
     """
     # synthetic dataset
     vtrain, vbase, vquery, ids_gnd = load_random(ntrain, nbase, nquery)
-    np.save('vbase', vbase[:10, :])
+    spio.savemat('vbase.mat', {'feat': vbase[:10, :]})
 
     return np.require(vtrain, np.single, requirements="C"),\
         np.require(vbase, np.single, requirements="C"),    \
